

<p align="center">
  <a href="https://www.arlun.io/gallery/">
    <img src="https://www.arlun.io/svg/arlunio.svg" width="50%" />
  </a>
</p>

![MIT License](https://img.shields.io/github/license/alcarney/arlunio.svg) [![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
|   | **Stable** | **Snapshot** |
|---|------------|--------------|
| **Docs** | | [![Documentation Status](https://github.com/swyddfa/arlunio/workflows/Docs%20Build/badge.svg?branch=develop)](https://www.arlun.io/docs/)|
| **Code** | [![Build Status](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=master)](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=master) [![codecov](https://codecov.io/gh/swyddfa/arlunio/branch/master/graph/badge.svg)](https://codecov.io/gh/swyddfa/arlunio)| [![Build Status](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=develop)](https://github.com/swyddfa/arlunio/workflows/Python%20Release/badge.svg?branch=develop)[![codecov](https://codecov.io/gh/swyddfa/arlunio/branch/develop/graph/badge.svg)](https://codecov.io/gh/swyddfa/arlunio)|
| **PyPi** | [![PyPi Version](https://img.shields.io/pypi/v/arlunio.svg)](https://pypi.org/project/arlunio) [![PyPi Supported Versions](https://img.shields.io/pypi/pyversions/arlunio.svg)](https://pypi.org/project/arlunio)|


**Arlunio is in early development, no guarantees we won't break something.**

Inspired by ideas in mathematics Arlunio is library that aims to make drawing
and animating with code not only possible but easy and fun!

<p align="center">
  <a href="https://www.arlun.io/gallery/">
    <img src="https://www.arlun.io/gallery/image/_example.png" width="50%" />
  </a>
</p>

Be sure to check out more examples in our [gallery](https://www.arlun.io/gallery/)

## Getting Started

Arlunio is available for Python 3.7+ and can be installed using `pip`. It comes
with an interactive tutorial based on Jupyter Notebooks:

```sh
$ pip install arlunio[examples]
$ arlunio tutorial
```

Alternatively you can find the tutorial in the [documentation](https://www.arlun.io/docs/users/getstarted/first-image.html)
or even try it out [in your browser](https://mybinder.org/v2/gh/swyddfa/arlunio/gh-pages?filepath=tutorial/users/getstarted/first-image.ipynb)!


## Contributing

Contributions are welcome! Check out the [contributing](https://www.arlun.io/docs/contributing/)
section of the documentation for more information
